@@ -1,16 +1,13 @@
 package Example::Schema::Result::Role;
 
-use strict;
-use warnings;
-
+use Example::Syntax;
 use base 'Example::Schema::Result';
 
 __PACKAGE__->table("role");
-__PACKAGE__->load_components(qw/Valiant::Result/);
 
 __PACKAGE__->add_columns(
-  id => { data_type => 'integer', is_nullable => 0, is_auto_increment => 1 },
-  label => { data_type => 'varchar', is_nullable => 0, size => '24' },
+  id => { data_type => 'integer', is_nullable => 0, is_auto_increment => 1, tags => ['checkbox_value'] },
+  label => { data_type => 'varchar', is_nullable => 0, size => '24', tags=>['checkbox_label'] },
 );
 
 __PACKAGE__->set_primary_key("id");
